pub struct AuthCall {
pub contract_id: AccountId,
pub state_init: Option<StateInit>,
pub msg: String,
pub attached_deposit: NearToken,
pub min_gas: Option<Gas>,
}Expand description
Call contract_id::on_auth(signer_id, msg) with signer_id
of intent.
Fields
contract_id: AccountIdCallee for on_auth()
state_init: Option<StateInit>Optionally initialize the receiver’s contract (Deterministic AccountId)
via state_init
right before calling on_auth() (in the same receipt).
msg: Stringmsg to pass in on_auth()
attached_deposit: NearTokenOptionally, attach deposit to on_auth()
call. The amount will be subtracted from user’s NEP-141 wNEAR
balance.
NOTE: the wNEAR will not be refunded in case of fail.
min_gas: Option<Gas>Optional minimum gas required for created promise to succeed.
By default, only MIN_GAS_DEFAULT is
required.
Remaining gas will be distributed evenly across all Function Call Promises created during execution of current receipt.
Implementations